@@ -4,9 +4,9 @@ use strict;
 use warnings;
 use Carp;
 
-our $SVNVERSION = (qw$Id: SEC.pm 1941 2023-10-31 09:49:58Z willem $)[2];
+our $SVNVERSION = (qw$Id: SEC.pm 1974 2024-04-21 08:17:48Z willem $)[2];
 our $VERSION;
-$VERSION = '1.22_01';
+$VERSION = '1.23_01';
 
 use base qw(Exporter DynaLoader);
 
@@ -99,7 +99,7 @@ sub key_difference {
 
 ########################################
 
-foreach (qw(DS CDS RRSIG)) {
+foreach (qw(RRSIG DS CDS)) {
 	Net::DNS::RR->new( type => $_ );			# pre-load to access class methods
 }
 
